@@ -186,15 +186,22 @@ def parse_gene(gene, genes_path=GENES_PATH):
 
 
 def gtracks(region, output, tracks=TRACKS, genes: str = 'GRCh38',
-            color_palette=COLOR_PALETTE, max=None, plot_type=['fill'],
-            overlay: bool = False, tmp_dir=None, width: int = 40,
-            genes_height: int = 2, gene_rows: int = 1, x_axis: str = 'top',
-            vlines_bed=None, bed_labels: bool = False, coord_regex=COORD_REGEX):
+            flank: int = 0, color_palette=COLOR_PALETTE, max=None,
+            plot_type=['fill'], overlay: bool = False, tmp_dir=None,
+            width: int = 40, genes_height: int = 2, gene_rows: int = 1,
+            x_axis: str = 'top', vlines_bed=None, bed_labels: bool = False,
+            coord_regex=COORD_REGEX):
     if not any(output.endswith(ext) for ext in ('pdf', 'png', 'svg')):
         raise RuntimeError(
             'Please make sure the output file extension is pdf, png, or svg')
     if coord_regex.match(region):
         chrom, xmin, xmax = parse_region(region)
+        xmin -= flank
+        xmax += flank
+    elif flank > 0:
+        chrom, xmin, xmax = parse_gene(region, genes_path=genes)
+        xmin -= flank
+        xmax += flank
     else:
         chrom, start, end = parse_gene(region, genes_path=genes)
         center = (end + start) / 2
@@ -246,6 +253,13 @@ def parse_arguments():
             'will use one of the included gene tracks. (default: GRCh37)'
         )
     )
+    parser.add_argument(
+        '--flank',
+        metavar='<int>',
+        type=int,
+        default=0,
+        help='add flanks to the plotting region'
+    )
     parser.add_argument(
         '--color-palette',
         metavar='<#color>',
@@ -335,7 +349,7 @@ def parse_arguments():
 def main():
     args = parse_arguments()
     gtracks(args.region, args.output, tracks=args.track, genes=args.genes,
-            color_palette=args.color_palette, max=args.max,
+            flank=args.flank, color_palette=args.color_palette, max=args.max,
             plot_type=args.plot_type, overlay=args.overlay,
             tmp_dir=args.tmp_dir, width=args.width,
             genes_height=args.genes_height, gene_rows=args.gene_rows,
